import { ChtmlFontData } from 'mathjax-full/mjs/output/chtml/FontData.js';
import { CommonMathJaxPagellaFontMixin } from './common.js';
import { normal } from './chtml/normal.js';
import { bold } from './chtml/bold.js';
import { italic } from './chtml/italic.js';
import { boldItalic } from './chtml/bold-italic.js';
import { doubleStruck } from './chtml/double-struck.js';
import { fraktur } from './chtml/fraktur.js';
import { frakturBold } from './chtml/fraktur-bold.js';
import { script } from './chtml/script.js';
import { scriptBold } from './chtml/script-bold.js';
import { sansSerif } from './chtml/sans-serif.js';
import { sansSerifBold } from './chtml/sans-serif-bold.js';
import { sansSerifItalic } from './chtml/sans-serif-italic.js';
import { sansSerifBoldItalic } from './chtml/sans-serif-bold-italic.js';
import { monospace } from './chtml/monospace.js';
import { smallop } from './chtml/smallop.js';
import { largeop } from './chtml/largeop.js';
import { size3 } from './chtml/size3.js';
import { size4 } from './chtml/size4.js';
import { size5 } from './chtml/size5.js';
import { size6 } from './chtml/size6.js';
import { texMathit } from './chtml/tex-mathit.js';
import { texCalligraphic } from './chtml/tex-calligraphic.js';
import { texCalligraphicBold } from './chtml/tex-calligraphic-bold.js';
import { texOldstyle } from './chtml/tex-oldstyle.js';
import { texOldstyleBold } from './chtml/tex-oldstyle-bold.js';
import { texVariant } from './chtml/tex-variant.js';
import { lfTp } from './chtml/lf-tp.js';
import { rtBt } from './chtml/rt-bt.js';
import { exMd } from './chtml/ex-md.js';
import { delimiters } from './chtml/delimiters.js';
const Base = CommonMathJaxPagellaFontMixin(ChtmlFontData);
export class MathJaxPagellaFont extends Base {
    constructor() {
        super(...arguments);
        this.cssFontPrefix = 'GP';
    }
}
MathJaxPagellaFont.NAME = 'MathJaxPagella';
MathJaxPagellaFont.OPTIONS = Object.assign(Object.assign({}, Base.OPTIONS), { fontURL: Base.OPTIONS.dynamicPrefix = '/chtml/woff', dynamicPrefix: Base.OPTIONS.dynamicPrefix + '/chtml/dynamic' });
MathJaxPagellaFont.defaultCssFamilyPrefix = 'MJX-GP-ZERO';
MathJaxPagellaFont.defaultVariantLetters = {
    'normal': '',
    'bold': 'B',
    'italic': 'I',
    'bold-italic': 'BI',
    'double-struck': 'DS',
    'fraktur': 'F',
    'bold-fraktur': 'FB',
    'script': 'S',
    'bold-script': 'SB',
    'sans-serif': 'SS',
    'bold-sans-serif': 'SSB',
    'sans-serif-italic': 'SSI',
    'sans-serif-bold-italic': 'SSBI',
    'monospace': 'M',
    '-smallop': 'SO',
    '-largeop': 'LO',
    '-size3': 'S3',
    '-size4': 'S4',
    '-size5': 'S5',
    '-size6': 'S6',
    '-tex-mathit': 'MI',
    '-tex-calligraphic': 'C',
    '-tex-bold-calligraphic': 'CB',
    '-tex-oldstyle': 'OS',
    '-tex-bold-oldstyle': 'OB',
    '-tex-variant': 'V',
    '-lf-tp': 'LT',
    '-rt-bt': 'RB',
    '-ex-md': 'EM'
};
MathJaxPagellaFont.defaultDelimiters = delimiters;
MathJaxPagellaFont.defaultChars = {
    'normal': normal,
    'bold': bold,
    'italic': italic,
    'bold-italic': boldItalic,
    'double-struck': doubleStruck,
    'fraktur': fraktur,
    'bold-fraktur': frakturBold,
    'script': script,
    'bold-script': scriptBold,
    'sans-serif': sansSerif,
    'bold-sans-serif': sansSerifBold,
    'sans-serif-italic': sansSerifItalic,
    'sans-serif-bold-italic': sansSerifBoldItalic,
    'monospace': monospace,
    '-smallop': smallop,
    '-largeop': largeop,
    '-size3': size3,
    '-size4': size4,
    '-size5': size5,
    '-size6': size6,
    '-tex-mathit': texMathit,
    '-tex-calligraphic': texCalligraphic,
    '-tex-bold-calligraphic': texCalligraphicBold,
    '-tex-oldstyle': texOldstyle,
    '-tex-bold-oldstyle': texOldstyleBold,
    '-tex-variant': texVariant,
    '-lf-tp': lfTp,
    '-rt-bt': rtBt,
    '-ex-md': exMd
};
MathJaxPagellaFont.defaultStyles = Object.assign(Object.assign({}, ChtmlFontData.defaultStyles), { '.GP-N': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-N'
    }, '.GP-B': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-B'
    }, '.GP-I': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-I'
    }, '.GP-BI': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-BI'
    }, '.GP-DS': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-DS'
    }, '.GP-F': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-F'
    }, '.GP-FB': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-FB'
    }, '.GP-S': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-S'
    }, '.GP-SB': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-SB'
    }, '.GP-SS': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-SS'
    }, '.GP-SSB': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-SSB'
    }, '.GP-SSI': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-SSI'
    }, '.GP-SSBI': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-SSBI'
    }, '.GP-M': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-M'
    }, '.GP-SO': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-SO'
    }, '.GP-LO': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-LO'
    }, '.GP-S3': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-S3'
    }, '.GP-S4': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-S4'
    }, '.GP-S5': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-S5'
    }, '.GP-S6': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-S6'
    }, '.GP-MI': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-MI'
    }, '.GP-C': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-C'
    }, '.GP-CB': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-CB'
    }, '.GP-OS': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-OS'
    }, '.GP-OB': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-OB'
    }, '.GP-V': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-V'
    }, '.GP-LT': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-LT'
    }, '.GP-RB': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-RB'
    }, '.GP-EM': {
        'font-family': 'MJX-GP-ZERO, MJX-GP-EM'
    } });
MathJaxPagellaFont.defaultFonts = Object.assign(Object.assign({}, ChtmlFontData.defaultFonts), { '@font-face /* MJX-GP-ZERO */': {
        'font-family': 'MJX-GP-ZERO',
        src: 'url("%%URL%%/mjx-gp-zero.woff") format("woff")'
    }, '@font-face /* MJX-BRK */': {
        'font-family': 'MJX-BRK',
        src: 'url("%%URL%%/mjx-gp-brk.woff") format("woff")'
    }, '@font-face /* MJX-GP-N */': {
        'font-family': 'MJX-GP-N',
        src: 'url("%%URL%%/mjx-gp-n.woff") format("woff")'
    }, '@font-face /* MJX-GP-B */': {
        'font-family': 'MJX-GP-B',
        src: 'url("%%URL%%/mjx-gp-b.woff") format("woff")'
    }, '@font-face /* MJX-GP-I */': {
        'font-family': 'MJX-GP-I',
        src: 'url("%%URL%%/mjx-gp-i.woff") format("woff")'
    }, '@font-face /* MJX-GP-BI */': {
        'font-family': 'MJX-GP-BI',
        src: 'url("%%URL%%/mjx-gp-bi.woff") format("woff")'
    }, '@font-face /* MJX-GP-DS */': {
        'font-family': 'MJX-GP-DS',
        src: 'url("%%URL%%/mjx-gp-ds.woff") format("woff")'
    }, '@font-face /* MJX-GP-F */': {
        'font-family': 'MJX-GP-F',
        src: 'url("%%URL%%/mjx-gp-f.woff") format("woff")'
    }, '@font-face /* MJX-GP-FB */': {
        'font-family': 'MJX-GP-FB',
        src: 'url("%%URL%%/mjx-gp-fb.woff") format("woff")'
    }, '@font-face /* MJX-GP-S */': {
        'font-family': 'MJX-GP-S',
        src: 'url("%%URL%%/mjx-gp-s.woff") format("woff")'
    }, '@font-face /* MJX-GP-SB */': {
        'font-family': 'MJX-GP-SB',
        src: 'url("%%URL%%/mjx-gp-sb.woff") format("woff")'
    }, '@font-face /* MJX-GP-SS */': {
        'font-family': 'MJX-GP-SS',
        src: 'url("%%URL%%/mjx-gp-ss.woff") format("woff")'
    }, '@font-face /* MJX-GP-SSB */': {
        'font-family': 'MJX-GP-SSB',
        src: 'url("%%URL%%/mjx-gp-ssb.woff") format("woff")'
    }, '@font-face /* MJX-GP-SSI */': {
        'font-family': 'MJX-GP-SSI',
        src: 'url("%%URL%%/mjx-gp-ssi.woff") format("woff")'
    }, '@font-face /* MJX-GP-SSBI */': {
        'font-family': 'MJX-GP-SSBI',
        src: 'url("%%URL%%/mjx-gp-ssbi.woff") format("woff")'
    }, '@font-face /* MJX-GP-M */': {
        'font-family': 'MJX-GP-M',
        src: 'url("%%URL%%/mjx-gp-m.woff") format("woff")'
    }, '@font-face /* MJX-GP-SO */': {
        'font-family': 'MJX-GP-SO',
        src: 'url("%%URL%%/mjx-gp-so.woff") format("woff")'
    }, '@font-face /* MJX-GP-LO */': {
        'font-family': 'MJX-GP-LO',
        src: 'url("%%URL%%/mjx-gp-lo.woff") format("woff")'
    }, '@font-face /* MJX-GP-S3 */': {
        'font-family': 'MJX-GP-S3',
        src: 'url("%%URL%%/mjx-gp-s3.woff") format("woff")'
    }, '@font-face /* MJX-GP-S4 */': {
        'font-family': 'MJX-GP-S4',
        src: 'url("%%URL%%/mjx-gp-s4.woff") format("woff")'
    }, '@font-face /* MJX-GP-S5 */': {
        'font-family': 'MJX-GP-S5',
        src: 'url("%%URL%%/mjx-gp-s5.woff") format("woff")'
    }, '@font-face /* MJX-GP-S6 */': {
        'font-family': 'MJX-GP-S6',
        src: 'url("%%URL%%/mjx-gp-s6.woff") format("woff")'
    }, '@font-face /* MJX-GP-MI */': {
        'font-family': 'MJX-GP-MI',
        src: 'url("%%URL%%/mjx-gp-mi.woff") format("woff")'
    }, '@font-face /* MJX-GP-C */': {
        'font-family': 'MJX-GP-C',
        src: 'url("%%URL%%/mjx-gp-c.woff") format("woff")'
    }, '@font-face /* MJX-GP-CB */': {
        'font-family': 'MJX-GP-CB',
        src: 'url("%%URL%%/mjx-gp-cb.woff") format("woff")'
    }, '@font-face /* MJX-GP-OS */': {
        'font-family': 'MJX-GP-OS',
        src: 'url("%%URL%%/mjx-gp-os.woff") format("woff")'
    }, '@font-face /* MJX-GP-OB */': {
        'font-family': 'MJX-GP-OB',
        src: 'url("%%URL%%/mjx-gp-ob.woff") format("woff")'
    }, '@font-face /* MJX-GP-V */': {
        'font-family': 'MJX-GP-V',
        src: 'url("%%URL%%/mjx-gp-v.woff") format("woff")'
    }, '@font-face /* MJX-GP-LT */': {
        'font-family': 'MJX-GP-LT',
        src: 'url("%%URL%%/mjx-gp-lt.woff") format("woff")'
    }, '@font-face /* MJX-GP-RB */': {
        'font-family': 'MJX-GP-RB',
        src: 'url("%%URL%%/mjx-gp-rb.woff") format("woff")'
    }, '@font-face /* MJX-GP-EM */': {
        'font-family': 'MJX-GP-EM',
        src: 'url("%%URL%%/mjx-gp-em.woff") format("woff")'
    } });
MathJaxPagellaFont.dynamicFiles = ChtmlFontData.defineDynamicFiles([
    ['latin', {
            'normal': [
                [0xC0, 0xD6], [0xD8, 0xEF], [0xF1, 0xF6], [0xF8, 0x130], [0x132, 0x137], [0x139, 0x148], [0x14A, 0x165], [0x168, 0x17F], 0x18E, 0x192, 0x1A0, 0x1A1, 0x1AF, 0x1B0, [0x1CD, 0x1D4], [0x1D7, 0x1DD], 0x1E6, 0x1E7, 0x1EA, 0x1EB, 0x1F0, 0x1F4, 0x1F5, [0x1FA, 0x201], 0x204, 0x205, 0x208, 0x209, 0x20C, 0x20D, 0x210, 0x211, 0x214, 0x215, [0x218, 0x21B], [0x1E0C, 0x1E0F], [0x1E24, 0x1E27], 0x1E2A, 0x1E2B, 0x1E2E, 0x1E2F, [0x1E36, 0x1E39], [0x1E42, 0x1E47], [0x1E58, 0x1E5D], 0x1E62, 0x1E63, [0x1E6C, 0x1E6F], [0x1E80, 0x1E85], 0x1E92, 0x1E93, 0x1E97, 0x1E9E, [0x1EA0, 0x1EF9]
            ]
        }],
    ['latin-b', {
            'bold': [
                [0xC0, 0xD6], [0xD8, 0xEF], [0xF1, 0xF6], [0xF8, 0x130], [0x132, 0x137], [0x139, 0x148], [0x14A, 0x165], [0x168, 0x17F], 0x18E, 0x192, 0x1A0, 0x1A1, 0x1AF, 0x1B0, [0x1CD, 0x1D4], [0x1D7, 0x1DD], 0x1E6, 0x1E7, 0x1EA, 0x1EB, 0x1F0, 0x1F4, 0x1F5, [0x1FA, 0x201], 0x204, 0x205, 0x208, 0x209, 0x20C, 0x20D, 0x210, 0x211, 0x214, 0x215, [0x218, 0x21B], [0x1E0C, 0x1E0F], [0x1E24, 0x1E27], 0x1E2A, 0x1E2B, 0x1E2E, 0x1E2F, [0x1E36, 0x1E39], [0x1E42, 0x1E47], [0x1E58, 0x1E5D], 0x1E62, 0x1E63, [0x1E6C, 0x1E6F], [0x1E80, 0x1E85], 0x1E92, 0x1E93, 0x1E97, 0x1E9E, [0x1EA0, 0x1EF9]
            ]
        }],
    ['latin-i', {
            'italic': [
                [0xC0, 0xD6], [0xD8, 0xEF], [0xF1, 0xF6], [0xF8, 0x130], [0x132, 0x137], [0x139, 0x148], [0x14A, 0x165], [0x168, 0x17F], 0x18E, 0x192, 0x1A0, 0x1A1, 0x1AF, 0x1B0, [0x1CD, 0x1D4], [0x1D7, 0x1DD], 0x1E6, 0x1E7, 0x1EA, 0x1EB, 0x1F0, 0x1F4, 0x1F5, [0x1FA, 0x201], 0x204, 0x205, 0x208, 0x209, 0x20C, 0x20D, 0x210, 0x211, 0x214, 0x215, [0x218, 0x21B], [0x1E0C, 0x1E0F], [0x1E24, 0x1E27], 0x1E2A, 0x1E2B, 0x1E2E, 0x1E2F, [0x1E36, 0x1E39], [0x1E42, 0x1E47], [0x1E58, 0x1E5D], 0x1E62, 0x1E63, [0x1E6C, 0x1E6F], [0x1E80, 0x1E85], 0x1E92, 0x1E93, 0x1E97, 0x1E9E, [0x1EA0, 0x1EF9]
            ]
        }],
    ['latin-bi', {
            'bold-italic': [
                [0xC0, 0xD6], [0xD8, 0xEF], [0xF1, 0xF6], [0xF8, 0x130], [0x132, 0x137], [0x139, 0x148], [0x14A, 0x165], [0x168, 0x17F], 0x18E, 0x192, 0x1A0, 0x1A1, 0x1AF, 0x1B0, [0x1CD, 0x1D4], [0x1D7, 0x1DD], 0x1E6, 0x1E7, 0x1EA, 0x1EB, 0x1F0, 0x1F4, 0x1F5, [0x1FA, 0x201], 0x204, 0x205, 0x208, 0x209, 0x20C, 0x20D, 0x210, 0x211, 0x214, 0x215, [0x218, 0x21B], [0x1E0C, 0x1E0F], [0x1E24, 0x1E27], 0x1E2A, 0x1E2B, 0x1E2E, 0x1E2F, [0x1E36, 0x1E39], [0x1E42, 0x1E47], [0x1E58, 0x1E5D], 0x1E62, 0x1E63, [0x1E6C, 0x1E6F], [0x1E80, 0x1E85], 0x1E92, 0x1E93, 0x1E97, 0x1E9E, [0x1EA0, 0x1EF9]
            ]
        }],
    ['double-struck', {
            'normal': [
                0x2102, 0x210D, 0x2115, 0x2119, 0x211A, 0x211D, 0x2124, [0x213C, 0x2140], [0x2145, 0x2149], 0x1D538, 0x1D539, [0x1D53B, 0x1D53E], [0x1D540, 0x1D544], 0x1D546, [0x1D54A, 0x1D550], [0x1D552, 0x1D56B], [0x1D7D8, 0x1D7E1]
            ],
            'double-struck': [
                0x131, 0x237
            ]
        }, [0x2140]],
    ['fraktur', {
            'normal': [
                0x210C, 0x2111, 0x211C, 0x2128, 0x212D, 0x1D504, 0x1D505, [0x1D507, 0x1D50A], [0x1D50D, 0x1D514], [0x1D516, 0x1D51C], [0x1D51E, 0x1D537], [0x1D56C, 0x1D59F]
            ],
            'fraktur': [
                0x131, 0x237
            ],
            'bold-fraktur': [
                0x131, 0x237
            ]
        }],
    ['script', {
            'normal': [
                0x210A, 0x210B, 0x2110, 0x2112, 0x2113, 0x2118, 0x211B, 0x212C, [0x212F, 0x2131], 0x2133, 0x2134, 0x1D49C, 0x1D49E, 0x1D49F, 0x1D4A2, 0x1D4A5, 0x1D4A6, [0x1D4A9, 0x1D4AC], [0x1D4AE, 0x1D4B9], 0x1D4BB, [0x1D4BD, 0x1D4C3], [0x1D4C5, 0x1D503]
            ],
            'script': [
                0x131, 0x237
            ],
            'bold-script': [
                0x131, 0x237
            ]
        }],
    ['sans-serif', {
            'normal': [
                [0x1D5A0, 0x1D66F], [0x1D7E2, 0x1D7F5]
            ],
            'sans-serif': [
                0x131, 0x237
            ],
            'bold-sans-serif': [
                0x131, 0x237
            ],
            'sans-serif-italic': [
                0x131, 0x237
            ],
            'sans-serif-bold-italic': [
                0x131, 0x237
            ]
        }],
    ['monospace', {
            'normal': [
                [0x1D670, 0x1D6A3], [0x1D7F6, 0x1D7FF]
            ],
            'monospace': [
                0x131, 0x237
            ]
        }],
    ['calligraphic', {
            '-tex-calligraphic': [
                [0x41, 0x5A]
            ],
            '-tex-bold-calligraphic': [
                [0x41, 0x5A]
            ]
        }],
    ['symbols', {
            'normal': [
                0xA1, 0xA2, 0xA4, 0xA6, [0xA9, 0xAB], 0xAD, 0xAE, [0xBA, 0xBF], 0xE3F, 0x200C, 0x200D, 0x2017, 0x201A, 0x201E, 0x2022, 0x2030, 0x2031, [0x2039, 0x203B], 0x203D, 0x203F, 0x2040, 0x2045, 0x2046, 0x2052, 0x2054, 0x20A1, 0x20A6, 0x20A9, 0x20AB, 0x20B1, 0x20B2, 0x20BD, 0x20BF, 0x2103, 0x2109, 0x2116, 0x2117, 0x211E, 0x2120, 0x2122, 0x212E, 0x2300, 0x2305, 0x2306, 0x2422, 0x2423, 0x2E18, 0x2E40, 0x3016, 0x3017, [0xFB00, 0xFB04], 0xFEFF
            ],
            '-largeop': [
                0x2140
            ]
        }, [0x2017]],
    ['symbols-b-i', {
            'bold': [
                0xA1, 0xA2, 0xA4, 0xA6, [0xA9, 0xAB], 0xAD, 0xAE, [0xBA, 0xBF], 0xE3F, 0x200C, 0x200D, 0x2017, 0x201A, 0x201E, 0x2022, 0x2030, 0x2031, [0x2039, 0x203B], 0x203D, 0x203F, 0x2040, 0x2045, 0x2046, 0x2052, 0x2054, 0x20A1, 0x20A6, 0x20A9, 0x20AB, 0x20B1, 0x20B2, 0x20BD, 0x20BF, 0x2103, 0x2109, 0x2116, 0x2117, 0x211E, 0x2120, 0x2122, 0x212E, 0x2300, 0x2305, 0x2306, 0x2422, 0x2423, 0x2E18, 0x2E40, 0x3016, 0x3017
            ],
            'italic': [
                [0xA1, 0xA7], [0xA9, 0xAE], 0xB1, [0xB5, 0xB7], [0xBA, 0xBF], 0xD7, 0xF0, 0xF7, 0xE3F, 0x2020, 0x2021, 0x2030, 0x2031, 0x203D, 0x203F, 0x2040, 0x2052, 0x2054, 0x20A1, 0x20A6, 0x20A9, 0x20AB, 0x20B1, 0x20B2, 0x20BD, 0x20BF, 0x2103, 0x2109, 0x2116, 0x2117, 0x211E, 0x2120, 0x2122, 0x212E, 0x2422, 0x2423, 0x2E18, 0x2E40, [0xFB00, 0xFB04]
            ],
            'bold-italic': [
                [0xA1, 0xA7], [0xA9, 0xAE], 0xB1, [0xB5, 0xB7], [0xBA, 0xBF], 0xD7, 0xF0, 0xF7, 0xE3F, 0x2020, 0x2021, 0x2030, 0x2031, 0x203D, 0x203F, 0x2040, 0x2052, 0x2054, 0x20A1, 0x20A6, 0x20A9, 0x20AB, 0x20B1, 0x20B2, 0x20BD, 0x20BF, 0x2103, 0x2109, 0x2116, 0x2117, 0x211E, 0x2120, 0x2122, 0x212E, 0x2422, 0x2423, 0x2E18, 0x2E40, [0xFB00, 0xFB04]
            ]
        }],
    ['arrows', {
            'normal': [
                0x219C, 0x219D, 0x219F, 0x21A1, 0x21A5, 0x21A7, 0x21AD, [0x21AF, 0x21B5], [0x21D6, 0x21D9], 0x21DC, 0x21DD, [0x21E6, 0x21E9], 0x21F3, 0x27A1, 0x27F4, 0x27FF, 0x2906, 0x2907, 0x2933, 0x294C, 0x294D, 0x294F, 0x2951, 0x295C, 0x295D, 0x2960, 0x2961, [0x2B04, 0x2B07], 0x2B0C, 0x2B0D, 0x2B31, 0x2B33, 0x2B3F
            ],
            'bold': [
                0x219C, 0x219D, 0x219F, 0x21A1, 0x21A5, 0x21A7, 0x21AD, [0x21AF, 0x21B5], [0x21D6, 0x21D9], 0x21DC, 0x21DD, [0x21E6, 0x21E9], 0x21F3, 0x27A1, 0x27F4, 0x27FF, 0x2906, 0x2907, 0x2933, [0x2B04, 0x2B07], 0x2B0C, 0x2B0D, 0x2B31, 0x2B33, 0x2B3F
            ],
            '-largeop': [
                0x2191, 0x2193, [0x2195, 0x219B], [0x219E, 0x21A3], 0x21A5, 0x21A7, [0x21A9, 0x21AE], [0x21B0, 0x21B3], 0x21B6, 0x21B7, [0x21BC, 0x21CF], 0x21D1, 0x21D3, [0x21D5, 0x21DB], [0x21E6, 0x21E9], 0x21F3, 0x21F5, 0x21F6, [0x2B04, 0x2B07], 0x2B0C, 0x2B0D, 0x2B31
            ],
            '-lf-tp': [
                [0x21E6, 0x21E9], 0x2907, 0x2B05, 0x2B06
            ],
            '-rt-bt': [
                [0x21E6, 0x21E9], 0x2906, 0x2B07, 0x2B0C
            ],
            '-ex-md': [
                0x21E6, 0x21E7, 0x2B05, 0x2B06
            ]
        }, [0x219F, [0x2196, 0x2199], 0x21A1, 0x21A5, 0x21A7, 0x21AD, [0x21B0, 0x21B3], 0x21B6, 0x21B7, [0x21D6, 0x21D9], 0x21DC, 0x21DD, [0x21E6, 0x21E9], 0x21F3, 0x27A1, 0x27FD, 0x27FE, 0x2906, 0x2907, 0x294C, 0x294D, 0x294F, 0x2951, 0x295C, 0x295D, 0x2960, 0x2961, [0x2B04, 0x2B07], 0x2B0C, 0x2B0D, 0x2B31]],
    ['accents', {
            'normal': [
                0xB8, 0x2BE, 0x2BF, 0x2DB, 0x2DD, 0x309, 0x30B, 0x30F, 0x311, 0x323, [0x326, 0x328], [0x32C, 0x333], 0x33F, 0x34D, 0x361, [0x20D3, 0x20D5], 0x20D8, [0x20DD, 0x20DF], [0x20E4, 0x20E6], [0x20E8, 0x20EB], 0x20F0
            ],
            '-smallop': [
                0x311, [0x32C, 0x330], 0x332, 0x333, 0x33F, 0x34D
            ],
            '-largeop': [
                0x311, [0x32C, 0x330]
            ],
            '-size3': [
                0x311, [0x32C, 0x330]
            ],
            '-size4': [
                0x311, [0x32C, 0x330]
            ],
            '-size5': [
                0x311, [0x32C, 0x330]
            ],
            '-size6': [
                0x311, [0x32C, 0x330]
            ],
            '-ex-md': [
                0x332, 0x333, 0x33F, 0x34D
            ]
        }, [0x311, [0x32C, 0x330], 0x332, 0x333, 0x33F, 0x34D, 0x20E9]],
    ['accents-b-i', {
            'bold': [
                0xB8, 0x2BE, 0x2BF, 0x2DB, 0x2DD, 0x309, 0x30B, 0x30F, 0x311, 0x323, [0x326, 0x328], [0x32C, 0x333], 0x33F, 0x34D, 0x361, [0x20D3, 0x20D5], 0x20D8, [0x20DD, 0x20DF], [0x20E4, 0x20E6], [0x20E8, 0x20EB], 0x20F0
            ],
            'italic': [
                0xB8, 0x2BE, 0x2BF, 0x2DB, 0x2DD, 0x309, 0x30B, 0x30F, 0x311, 0x323, [0x326, 0x328], [0x32C, 0x333], 0x33F, 0x34D, 0x361, [0x20D0, 0x20D8], [0x20DB, 0x20DF], 0x20E1, [0x20E4, 0x20E6], [0x20E8, 0x20F0]
            ],
            'bold-italic': [
                0xB8, 0x2BE, 0x2BF, 0x2DB, 0x2DD, 0x309, 0x30B, 0x30F, 0x311, 0x323, [0x326, 0x328], [0x32C, 0x333], 0x33F, 0x34D, 0x361, [0x20D0, 0x20D8], [0x20DB, 0x20DF], 0x20E1, [0x20E4, 0x20E6], [0x20E8, 0x20F0]
            ]
        }],
    ['shapes', {
            'normal': [
                0x2500, 0x2502, 0x250C, 0x2510, 0x2514, 0x2518, 0x251C, 0x2524, 0x252C, 0x2534, 0x253C, 0x2581, 0x2588, [0x2591, 0x2593], 0x25AC, 0x25AD, [0x2660, 0x2667], 0x266A, [0x266D, 0x266F], 0x26AD, 0x26AE, 0x2713, 0x2720, 0x27A1, 0x2B1A
            ],
            'bold': [
                0x2500, 0x2502, 0x250C, 0x2510, 0x2514, 0x2518, 0x251C, 0x2524, 0x252C, 0x2534, 0x253C, 0x25AC, 0x25AD, [0x2660, 0x2667], 0x266A, [0x266D, 0x266F], 0x26AD, 0x26AE, 0x2713, 0x2720, 0x27A1, 0x2B1A
            ],
            'italic': [
                0x266A, 0x26AD, 0x26AE
            ],
            'bold-italic': [
                0x266A, 0x26AD, 0x26AE
            ]
        }],
    ['stretchy', {
            'normal': [
                0x2320, 0x2321, 0x23B2, 0x23B3
            ],
            'bold': [
                0x2320, 0x2321, 0x23B2, 0x23B3
            ],
            '-size3': [
                [0x222B, 0x2233], 0x2A0C, 0x2A11
            ],
            '-size4': [
                [0x222B, 0x2233], 0x2A0C, 0x2A11
            ],
            '-size5': [
                [0x222B, 0x2233], 0x2A0C, 0x2A11
            ],
            '-size6': [
                [0x222B, 0x2233], 0x2A0C, 0x2A11
            ],
            '-lf-tp': [
                [0x222B, 0x222D], 0x2A0C
            ],
            '-rt-bt': [
                [0x222B, 0x222D], 0x2A0C
            ],
            '-ex-md': [
                0x222C, 0x222D, 0x2A0C
            ]
        }, [[0x222B, 0x2233], 0x2A0C, 0x2A11, 0x2140, [0x220F, 0x2211], [0x22A2, 0x22A5], [0x22C0, 0x22C3], [0x2A00, 0x2A06], 0x2A09]],
    ['variants', {
            '-tex-variant': [
                0x22, [0x27, 0x2B], 0x2D, 0x2F, [0x3C, 0x3E], 0x40, [0x5B, 0x5D], 0x60, [0x7B, 0x7E], 0xA9, 0xAA, 0xAC, [0xAE, 0xB3], 0xB6, 0xB9, 0xBA, 0xD7, 0xF7, 0x12A, 0x12B, 0x2014, 0x2016, 0x2044, 0x2061, 0x2070, 0x2071, [0x2074, 0x208E], 0x2E40
            ]
        }],
    ['PUA', {
            'normal': [
                0xE000, 0xE001, 0xE803, 0xEA1F, 0xEA26, 0xEA35, 0xEA3E, 0xEB03, 0xEB04, 0xEB0F, 0xEB16, 0xEB19, 0xEB1E, 0xEB1F, 0xEB35, 0xEB36, 0xEB3A, 0xEB3B, 0xEB40, 0xEB48, 0xEB49, 0xEB4D, 0xEB61, 0xEB63, 0xEB6E, 0xEB6F, [0xEC08, 0xEC0E], 0xEC10, 0xEC11, 0xF6DE
            ],
            'bold': [
                0xE000, 0xE001, 0xE803, 0xEB03, 0xEB04, 0xEB0F, 0xEB16, 0xEB1E, 0xEB1F, 0xEB35, 0xEB36, 0xEB3A, 0xEB3B, 0xEB40, 0xEB48, 0xEB49, 0xEB4D, 0xEB61, 0xEB63, 0xEB6E, 0xEB6F, [0xEC08, 0xEC0E], 0xEC10, 0xEC11, 0xF6DE
            ],
            'italic': [
                0xE000, 0xE001, 0xE803, 0xEB03, 0xEB04, 0xEB0F, 0xEB16, 0xEB1E, 0xEB1F, 0xEB35, 0xEB36, 0xEB3A, 0xEB3B, 0xEB40, 0xEB48, 0xEB49, 0xEB4D, 0xEB61, 0xEB63, 0xEB6E, 0xEB6F, [0xEC08, 0xEC0E], 0xEC10, 0xEC11, 0xF6DE
            ],
            'bold-italic': [
                0xE000, 0xE001, 0xE803, 0xEB03, 0xEB04, 0xEB0F, 0xEB16, 0xEB1E, 0xEB1F, 0xEB35, 0xEB36, 0xEB3A, 0xEB3B, 0xEB40, 0xEB48, 0xEB49, 0xEB4D, 0xEB61, 0xEB63, 0xEB6E, 0xEB6F, [0xEC08, 0xEC0E], 0xEC10, 0xEC11, 0xF6DE
            ]
        }]
]);
//# sourceMappingURL=chtml.js.map